/*
 * sat68kdb: Sega Saturn MC68EC000 Debugger
 * Bart Trzynadlowski
 */

/*
 * satintrf.h: Sega Saturn interface header
 */


/*
 * Definitions (public)
 *
 * Note: The register offsets will not change, it is perfectly acceptable to
 * hard code them, if you wish.
 */

#define CMND_TRACE      1
#define CMND_READPC     2
#define CMND_READREG    3
#define CMND_WRITEREG   4
#define CMND_READSR     5
#define CMND_WRITESR    6
#define CMND_WRITEPC    7
#define CMND_READXSP    8

#define CMND_READMEMB   0xf9
#define CMND_WRITEMEMB  0xfa
#define CMND_READMEMW   0xfb
#define CMND_WRITEMEMW  0xfc
#define CMND_READMEML   0xfd
#define CMND_WRITEMEML  0xfe
#define CMND_RESET      0xff

#define REG_D0  0
#define REG_D1  4
#define REG_D2  8
#define REG_D3  12
#define REG_D4  16
#define REG_D5  20
#define REG_D6  24
#define REG_D7  28
#define REG_A0  32
#define REG_A1  36
#define REG_A2  40
#define REG_A3  44
#define REG_A4  48
#define REG_A5  52
#define REG_A6  56
#define REG_A7  60


/*
 * Macros
 */

#define WORDSWAP(d)     ((d << 8) & 0xff00) | ((d >> 8) & 0xff)
#define DWORDSWAP(d)    ((d & 0xff) << 24) | ((d & 0xff00) << 8) | ((d & 0xff0000) >> 8) | ((d & 0xff000000) >> 24)


/*
 * Basic Data Types
 */

typedef unsigned int        UINT32;
typedef signed int          INT32;
typedef unsigned short      UINT16;
typedef signed short        INT16;
typedef unsigned char       UINT8;
typedef signed char         INT8;


/*
 * Data
 */

extern UINT32   sat68kdb_bytes_transferred;


/*
 * Functions
 */

UINT32  sat68kdb_Command(UINT16, UINT32, UINT32);
void    sat68kdb_Init(UINT16, UINT8 *, UINT32);
void    sat68kdb_Deinit();
